<*+O2EXTENSIONS*>
<* ALIGNMENT = "8" *>
MODULE iuplib;

CONST
    NAME = "IUP - Portable User Interface";
    COPYRIGHT = "Copyright (C) 1994-2012 Tecgraf, PUC-Rio.";
    DESCRIPTION = "Multi-platform toolkit for building graphical user interfaces.";
    VERSION = "3.7";  (* bug fixes are reported only by IupVersion functions *)
    VERSION_NUMBER = 307000;
    VERSION_DATE = "2012/11/29";  (* does not include bug fix releases *)

TYPE
    Ihandle*      = POINTER TO RECORD END;
    IhandleList*  = ARRAY OF Ihandle;
    --Istring*      = POINTER ["C"] TO ARRAY OF CHAR;
    Istring*      = POINTER ["C"] TO CHAR;
    IstringList*  = ARRAY OF Istring;
    Ipointer*     = POINTER TO RECORD END;
    IpointerList* = ARRAY OF Ipointer;
    Icallback*    = INTEGER;
    Iparamcb*     = PROCEDURE ["C"] (dialog: Ihandle; param_index: INTEGER; user_data: Ipointer);
    Inull*        = POINTER TO RECORD END;

(* MAIN API *)

PROCEDURE ["C"] / IupOpen*          (VAR argc: INTEGER; VAR argv: IstringList): INTEGER;
PROCEDURE ["C"] / IupClose*        ;
PROCEDURE ["C"] / IupImageLibOpen* ;
PROCEDURE ["C"] / IupMainLoop*      (): INTEGER;
PROCEDURE ["C"] / IupLoopStep*      (): INTEGER;
PROCEDURE ["C"] / IupLoopStepWait*  (): INTEGER;
PROCEDURE ["C"] / IupMainLoopLevel* (): INTEGER;
PROCEDURE ["C"] / IupFlush*        ;
PROCEDURE ["C"] / IupExitLoop*     ;

PROCEDURE ["C"] / IupRecordInput* (filename: Istring; mode: INTEGER): INTEGER;
PROCEDURE ["C"] / IupPlayInput*   (filename: Istring): INTEGER;

PROCEDURE ["C"] / IupUpdate*          (ih: Ihandle);
PROCEDURE ["C"] / IupUpdateChildren*  (ih: Ihandle);
PROCEDURE ["C"] / IupRedraw*          (ih: Ihandle; children: INTEGER);
PROCEDURE ["C"] / IupRefresh*         (ih: Ihandle);
PROCEDURE ["C"] / IupRefreshChildren* (ih: Ihandle);

PROCEDURE ["C"] / IupMapFont*    (iupfont:    Istring): Istring;
PROCEDURE ["C"] / IupUnMapFont*  (driverfont: Istring): Istring;
PROCEDURE ["C"] / IupHelp*       (url:        Istring): INTEGER;
PROCEDURE ["C"] / IupLoad*       (filename:   Istring): Istring;
PROCEDURE ["C"] / IupLoadBuffer* (buffer:      Istring): Istring;

PROCEDURE ["C"] / IupVersion*       (): Istring;
PROCEDURE ["C"] / IupVersionDate*   (): Istring;
PROCEDURE ["C"] / IupVersionNumber* (): INTEGER;
PROCEDURE ["C"] / IupSetLanguage*   (lng: Istring);
PROCEDURE ["C"] / IupGetLanguage*   (): Istring;

PROCEDURE ["C"] / IupDestroy*        (ih:    Ihandle);
PROCEDURE ["C"] / IupDetach*         (child: Ihandle);
PROCEDURE ["C"] / IupAppend*         (ih, child: Ihandle): Ihandle;
PROCEDURE ["C"] / IupInsert*         (ih, ref_child, child: Ihandle): Ihandle;
PROCEDURE ["C"] / IupGetChild*       (ih: Ihandle; pos: INTEGER): Ihandle;
PROCEDURE ["C"] / IupGetChildPos*    (ih, child: Ihandle): INTEGER;
PROCEDURE ["C"] / IupGetChildCount*  (ih: Ihandle): INTEGER;
PROCEDURE ["C"] / IupGetNextChild*   (ih, child: Ihandle): Ihandle;
PROCEDURE ["C"] / IupGetBrother*     (ih: Ihandle): Ihandle;
PROCEDURE ["C"] / IupGetParent*      (ih: Ihandle): Ihandle;
PROCEDURE ["C"] / IupGetDialog*      (ih: Ihandle): Ihandle;
PROCEDURE ["C"] / IupGetDialogChild* (ih: Ihandle; name: Istring): Ihandle;
PROCEDURE ["C"] / IupReparent*       (ih, new_parent, ref_child: Ihandle): INTEGER;

PROCEDURE ["C"] / IupPopup*  (ih: Ihandle; x, y: INTEGER): INTEGER;
PROCEDURE ["C"] / IupShow*   (ih: Ihandle): INTEGER;
PROCEDURE ["C"] / IupShowXY* (ih: Ihandle; x, y: INTEGER): INTEGER;
PROCEDURE ["C"] / IupHide*   (ih: Ihandle): INTEGER;
PROCEDURE ["C"] / IupMap*    (ih: Ihandle): INTEGER;
PROCEDURE ["C"] / IupUnmap*  (ih: Ihandle);

PROCEDURE ["C"] / IupSetAttribute*   (ih: Ihandle; name, value: Istring);
PROCEDURE ["C"] / IupStoreAttribute* (ih: Ihandle; name, value: Istring);
PROCEDURE ["C"] / IupSetAttributes*  (ih: Ihandle; str:  Istring): Ihandle;
PROCEDURE ["C"] / IupGetAttribute*   (ih: Ihandle; name: Istring): Istring;
PROCEDURE ["C"] / IupGetAttributes*  (ih: Ihandle): Istring;
PROCEDURE ["C"] / IupGetInt*         (ih: Ihandle; name: Istring): INTEGER;
PROCEDURE ["C"] / IupGetInt2*        (ih: Ihandle; name: Istring): INTEGER;
PROCEDURE ["C"] / IupGetIntInt*      (ih: Ihandle; name: Istring; i1, i2: INTEGER): INTEGER;
PROCEDURE ["C"] / IupGetFloat*       (ih: Ihandle; name: Istring): REAL;
(*
PROCEDURE ["C"] / IupSetfAttribute*    (ih: Ihandle; name, format: Istring; ...);*)
PROCEDURE ["C"] / IupResetAttribute*   (ih: Ihandle; name: Istring);
PROCEDURE ["C"] / IupGetAllAttributes* (ih: Ihandle; names: IstringList; n: INTEGER): INTEGER;
(*
PROCEDURE ["C"] / IupSetAtt*           (handle_name: Istring; ih: Ihandle; name: Istring; ...): Ihandle;*)

PROCEDURE ["C"] / IupSetAttributeId*   (ih: Ihandle; name: Istring; id: INTEGER; value: Istring);
PROCEDURE ["C"] / IupStoreAttributeId* (ih: Ihandle; name: Istring; id: INTEGER; value: Istring);
PROCEDURE ["C"] / IupGetAttributeId*   (ih: Ihandle; name: Istring; id: INTEGER);
PROCEDURE ["C"] / IupGetFloatId*       (ih: Ihandle; name: Istring; id: INTEGER);
PROCEDURE ["C"] / IupGetIntId*         (ih: Ihandle; name: Istring; id: INTEGER);
(*
PROCEDURE ["C"] / IupSetfAttributeId*  (ih: Ihandle; name: Istring; id: INTEGER; format: Istring; ...);*)

PROCEDURE ["C"] / IupSetAttributeId2*   (ih: Ihandle; name: Istring; lin, col: INTEGER; value: Istring);
PROCEDURE ["C"] / IupStoreAttributeId2* (ih: Ihandle; name: Istring; lin, col: INTEGER; value: Istring);
PROCEDURE ["C"] / IupGetAttributeId2*   (ih: Ihandle; name: Istring; lin, col: INTEGER);
PROCEDURE ["C"] / IupGetIntId2*         (ih: Ihandle; name: Istring; lin, col: INTEGER);
PROCEDURE ["C"] / IupGetFloatId2*       (ih: Ihandle; name: Istring; lin, col: INTEGER);
(*
PROCEDURE ["C"] / IupSetfAttributeId2*  (ih: Ihandle; name: Istring; lin, col: INTEGER; format: Istring; ...);*)

PROCEDURE ["C"] / IupSetGlobal*   (name, value: Istring);
PROCEDURE ["C"] / IupStoreGlobal* (name, value: Istring);
PROCEDURE ["C"] / IupGetGlobal*   (name: Istring): Istring;

PROCEDURE ["C"] / IupSetFocus*      (ih: Ihandle): Ihandle;
PROCEDURE ["C"] / IupGetFocus*      (): Ihandle;
PROCEDURE ["C"] / IupPreviousField* (ih: Ihandle): Ihandle;
PROCEDURE ["C"] / IupNextField*     (ih: Ihandle): Ihandle;

PROCEDURE ["C"] / IupGetCallback*  (ih: Ihandle; name: Istring): Icallback;
PROCEDURE ["C"] / IupSetCallback*  (ih: Ihandle; name: Istring; func: Icallback): Icallback;
(*
PROCEDURE ["C"] / IupSetCallbacks* (ih: Ihandle; name: Istring; func: Icallback; ...): Ihandle;*)

PROCEDURE ["C"] / IupGetFunction*   (name: Istring): Icallback;
PROCEDURE ["C"] / IupSetFunction*   (name: Istring; func: Icallback): Icallback;
PROCEDURE ["C"] / IupGetActionName* (): Istring;

PROCEDURE ["C"] / IupGetHandle*     (name: Istring): Ihandle;
PROCEDURE ["C"] / IupSetHandle*     (name: Istring; ih: Ihandle): Ihandle;
PROCEDURE ["C"] / IupGetAllNames*   (names: IstringList; n: INTEGER): INTEGER;
PROCEDURE ["C"] / IupGetAllDialogs* (names: Istring; n: INTEGER): INTEGER;
PROCEDURE ["C"] / IupGetName*       (ih: Ihandle): Istring;

PROCEDURE ["C"] / IupSetAttributeHandle*       (ih: Ihandle; name: Istring; ih_named: Ihandle);
PROCEDURE ["C"] / IupGetAttributeHandle*       (ih: Ihandle; name: Istring): Ihandle;

PROCEDURE ["C"] / IupGetClassName*             (ih: Ihandle): Istring;
PROCEDURE ["C"] / IupGetClassType*             (ih: Ihandle): Istring;
PROCEDURE ["C"] / IupGetAllClasses*            (names: IstringList; n: INTEGER): INTEGER;
PROCEDURE ["C"] / IupGetClassAttributes*       (classname: Istring; names: IstringList; n: INTEGER): INTEGER;

PROCEDURE ["C"] / IupGetClassCallbacks*        (classname: Istring; names: IstringList; n: INTEGER): INTEGER;
PROCEDURE ["C"] / IupSaveClassAttributes*      (ih: Ihandle);
PROCEDURE ["C"] / IupCopyClassAttributes*      (src_ih, dst_ih: Ihandle);
PROCEDURE ["C"] / IupSetClassDefaultAttribute* (classname, name, value: Istring);
PROCEDURE ["C"] / IupClassMatch*               (ih: Ihandle; classname: Istring): INTEGER;
PROCEDURE ["C"] / IupCreate*                   (classname: Istring): Ihandle;
PROCEDURE ["C"] / IupCreatev*                  (classname: Istring; params: IpointerList): Ihandle;
PROCEDURE ["C"] / IupCreatep*                  (classname: Istring; first: Ipointer; null: Inull): Ihandle;

(* ELEMENTS *)

PROCEDURE ["C"] / IupFill*        (): Ihandle;
PROCEDURE ["C"] / IupRadio*       (child: Ihandle): Ihandle;
PROCEDURE ["C"] / IupVbox*        (child: Ihandle; null: Inull): Ihandle;
PROCEDURE ["C"] / IupVboxv*       (children: IhandleList): Ihandle;
PROCEDURE ["C"] / IupZbox*        (child: Ihandle; null: Inull): Ihandle;
PROCEDURE ["C"] / IupZboxv*       (children: IhandleList): Ihandle;
PROCEDURE ["C"] / IupHbox*        (child: Ihandle; null: Inull): Ihandle;
PROCEDURE ["C"] / IupHboxv*       (children: IhandleList): Ihandle;
PROCEDURE ["C"] / IupNormalizer*  (ih_first: Ihandle; null: Inull): Ihandle;
PROCEDURE ["C"] / IupNormalizerv* (ih_list: IhandleList): Ihandle;

PROCEDURE ["C"] / IupCbox*        (child: Ihandle; null: Inull): Ihandle;
PROCEDURE ["C"] / IupCboxv*       (children: IhandleList): Ihandle;
PROCEDURE ["C"] / IupSbox*        (child: Ihandle): Ihandle;
PROCEDURE ["C"] / IupSplit*       (child1, child2: Ihandle): Ihandle;
PROCEDURE ["C"] / IupScrollBox*   (child: Ihandle): Ihandle;

PROCEDURE ["C"] / IupFrame*       (child: Ihandle): Ihandle;

PROCEDURE ["C"] / IupImage*       (width, height: INTEGER; pixmap: Istring): Ihandle;
PROCEDURE ["C"] / IupImageRGB*    (width, height: INTEGER; pixmap: Istring): Ihandle;
PROCEDURE ["C"] / IupImageRGBA*   (width, height: INTEGER; pixmap: Istring): Ihandle;

PROCEDURE ["C"] / IupItem*        (title, action: Istring): Ihandle;
PROCEDURE ["C"] / IupSubmenu*     (title: Istring; child: Ihandle): Ihandle;
PROCEDURE ["C"] / IupSeparator*   (): Ihandle;
PROCEDURE ["C"] / IupMenu*        (child: Ihandle; null: Inull): Ihandle;
PROCEDURE ["C"] / IupMenuv*       (children: IhandleList): Ihandle;

PROCEDURE ["C"] / IupButton*      (title, action: Istring): Ihandle;
PROCEDURE ["C"] / IupCanvas*      (action: Istring): Ihandle;
PROCEDURE ["C"] / IupDialog*      (child: Ihandle): Ihandle;
PROCEDURE ["C"] / IupUser*        (): Ihandle;
PROCEDURE ["C"] / IupLabel*       (title: Istring): Ihandle;
PROCEDURE ["C"] / IupList*        (action: Istring): Ihandle;
PROCEDURE ["C"] / IupText*        (action: Istring): Ihandle;
PROCEDURE ["C"] / IupMultiLine*   (action: Istring): Ihandle;
PROCEDURE ["C"] / IupToggle*      (title, action: Istring): Ihandle;
PROCEDURE ["C"] / IupTimer*       (): Ihandle;
PROCEDURE ["C"] / IupClipboard*   (): Ihandle;
PROCEDURE ["C"] / IupProgressBar* (): Ihandle;
PROCEDURE ["C"] / IupVal*         (type: Istring): Ihandle;
PROCEDURE ["C"] / IupTabs*        (child: Ihandle; null: Inull): Ihandle;
PROCEDURE ["C"] / IupTabsv*       (children: IhandleList): Ihandle;
PROCEDURE ["C"] / IupTree*        (): Ihandle;

(* Deprecated controls use SPIN attribute of IupText *)
PROCEDURE ["C"] / IupSpin*    (): Ihandle;
PROCEDURE ["C"] / IupSpinbox* (child: Ihandle): Ihandle;

(* IupImage utility *)
PROCEDURE ["C"] / IupSaveImageAsText* (ih: Ihandle; file_name, format, name: Istring): INTEGER;

(* IupText utilities *)
PROCEDURE ["C"] / IupTextConvertLinColToPos* (ih: Ihandle; lin, col: INTEGER; VAR pos: INTEGER);
PROCEDURE ["C"] / IupTextConvertPosToLinCol* (ih: Ihandle; pos: INTEGER; VAR lin, col: INTEGER);

(* IupText, IupList and IupTree utility *)
PROCEDURE ["C"] / IupConvertXYToPos* (ih: Ihandle; x, y: INTEGER): INTEGER;

(* IupTree utilities *)
PROCEDURE ["C"] / IupTreeSetUserId* (ih: Ihandle; id: INTEGER; userid: Ipointer): INTEGER;
PROCEDURE ["C"] / IupTreeGetUserId* (ih: Ihandle; id: INTEGER): Ipointer;
PROCEDURE ["C"] / IupTreeGetId*     (ih: Ihandle; userid: Ipointer): INTEGER;

(* Deprecated IupTree utilities, use Iup*AttributeId functions *)
PROCEDURE ["C"] / IupTreeSetAttribute*   (ih: Ihandle; name: Istring; id: INTEGER; value: Istring);
PROCEDURE ["C"] / IupTreeStoreAttribute* (ih: Ihandle; name: Istring; id: INTEGER; value: Istring);
PROCEDURE ["C"] / IupTreeGetAttribute*   (ih: Ihandle; name: Istring; id: INTEGER): Istring;
PROCEDURE ["C"] / IupTreeGetInt*         (ih: Ihandle; name: Istring; id: INTEGER): INTEGER;
PROCEDURE ["C"] / IupTreeGetFloat*       (ih: Ihandle; name: Istring; id: INTEGER): REAL;
(*
PROCEDURE ["C"] / IupTreeSetfAttribute*      (ih: Ihandle; name: Istring; id: INTEGER; format: Istring; ...);*)
PROCEDURE ["C"] / IupTreeSetAttributeHandle* (ih: Ihandle; a: Istring; id: INTEGER; ih_named: Ihandle);

(* PRE-DEFINIDED DIALOGS *)

PROCEDURE ["C"] / IupFileDlg*    (): Ihandle;
PROCEDURE ["C"] / IupMessageDlg* (): Ihandle;
PROCEDURE ["C"] / IupColorDlg*   (): Ihandle;
PROCEDURE ["C"] / IupFontDlg*    (): Ihandle;

PROCEDURE ["C"] / IupGetFile*    (arg: Istring): INTEGER;
PROCEDURE ["C"] / IupMessage*    (title, msg: Istring);
(*
PROCEDURE ["C"] / IupMessagef*   (title, format: Istring; ...): INTEGER;*)
PROCEDURE ["C"] / IupAlarm*      (title, msg, b1, b2, b3: Istring): INTEGER;
(*
PROCEDURE ["C"] / IupScanf*      (format: Istring, ...): INTEGER;*)
PROCEDURE ["C"] / IupListDialog* (type: INTEGER; title: Istring; size: INTEGER; list: IstringList; op, max_col, max_lin: INTEGER; VAR marks: INTEGER): INTEGER;
PROCEDURE ["C"] / IupGetText*    (title, text: Istring): INTEGER;
PROCEDURE ["C"] / IupGetColor*   (x,y: INTEGER; r, g, b: Istring): INTEGER;

(*
PROCEDURE ["C"] / IupGetParam*  (title: Istring; action: Iparamcb; user_data: Ipointer; format: Istring; ...): INTEGER;*)
PROCEDURE ["C"] / IupGetParamv* (title: Istring; action: Iparamcb; user_data: Ipointer; format: Istring; param_count, param_extra: INTEGER; param_data: IpointerList): INTEGER;

PROCEDURE ["C"] / IupLayoutDialog*            (dialog: Ihandle): Ihandle;
PROCEDURE ["C"] / IupElementPropertiesDialog* (elem: Ihandle): Ihandle;

BEGIN
END iuplib.